import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a CapacityReservations. */
export declare class CapacityReservations {
    private readonly client;
    /**
     * Create a CapacityReservations.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * The operation to create or update a capacity reservation. Please note some properties can be set
     * only during capacity reservation creation. Please refer to https://aka.ms/CapacityReservation
     * for more details.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param parameters Parameters supplied to the Create capacity reservation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, parameters: Models.CapacityReservation, options?: msRest.RequestOptionsBase): Promise<Models.CapacityReservationsCreateOrUpdateResponse>;
    /**
     * The operation to update a capacity reservation.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param parameters Parameters supplied to the Update capacity reservation operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationsUpdateResponse>
     */
    update(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, parameters: Models.CapacityReservationUpdate, options?: msRest.RequestOptionsBase): Promise<Models.CapacityReservationsUpdateResponse>;
    /**
     * The operation to delete a capacity reservation. This operation is allowed only when all the
     * associated resources are disassociated from the capacity reservation. Please refer to
     * https://aka.ms/CapacityReservation for more details.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * The operation that retrieves information about the capacity reservation.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationsGetResponse>
     */
    get(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, options?: Models.CapacityReservationsGetOptionalParams): Promise<Models.CapacityReservationsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param callback The callback
     */
    get(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, callback: msRest.ServiceCallback<Models.CapacityReservation>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, options: Models.CapacityReservationsGetOptionalParams, callback: msRest.ServiceCallback<Models.CapacityReservation>): void;
    /**
     * Lists all of the capacity reservations in the specified capacity reservation group. Use the
     * nextLink property in the response to get the next page of capacity reservations.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationsListByCapacityReservationGroupResponse>
     */
    listByCapacityReservationGroup(resourceGroupName: string, capacityReservationGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.CapacityReservationsListByCapacityReservationGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param callback The callback
     */
    listByCapacityReservationGroup(resourceGroupName: string, capacityReservationGroupName: string, callback: msRest.ServiceCallback<Models.CapacityReservationListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByCapacityReservationGroup(resourceGroupName: string, capacityReservationGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CapacityReservationListResult>): void;
    /**
     * The operation to create or update a capacity reservation. Please note some properties can be set
     * only during capacity reservation creation. Please refer to https://aka.ms/CapacityReservation
     * for more details.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param parameters Parameters supplied to the Create capacity reservation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, parameters: Models.CapacityReservation, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * The operation to update a capacity reservation.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param parameters Parameters supplied to the Update capacity reservation operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, parameters: Models.CapacityReservationUpdate, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * The operation to delete a capacity reservation. This operation is allowed only when all the
     * associated resources are disassociated from the capacity reservation. Please refer to
     * https://aka.ms/CapacityReservation for more details.
     * @param resourceGroupName The name of the resource group.
     * @param capacityReservationGroupName The name of the capacity reservation group.
     * @param capacityReservationName The name of the capacity reservation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, capacityReservationGroupName: string, capacityReservationName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all of the capacity reservations in the specified capacity reservation group. Use the
     * nextLink property in the response to get the next page of capacity reservations.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CapacityReservationsListByCapacityReservationGroupNextResponse>
     */
    listByCapacityReservationGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.CapacityReservationsListByCapacityReservationGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByCapacityReservationGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.CapacityReservationListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByCapacityReservationGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CapacityReservationListResult>): void;
}
//# sourceMappingURL=capacityReservations.d.ts.map