import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a GalleryApplicationVersions. */
export declare class GalleryApplicationVersions {
    private readonly client;
    /**
     * Create a GalleryApplicationVersions.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * Create or update a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version is to be created.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be created.
     * Needs to follow semantic version name pattern: The allowed characters are digit and period.
     * Digits must be within the range of a 32-bit integer. Format:
     * <MajorVersion>.<MinorVersion>.<Patch>
     * @param galleryApplicationVersion Parameters supplied to the create or update gallery Application
     * Version operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.GalleryApplicationVersionsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, galleryApplicationVersion: Models.GalleryApplicationVersion, options?: msRest.RequestOptionsBase): Promise<Models.GalleryApplicationVersionsCreateOrUpdateResponse>;
    /**
     * Update a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version is to be updated.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be updated.
     * Needs to follow semantic version name pattern: The allowed characters are digit and period.
     * Digits must be within the range of a 32-bit integer. Format:
     * <MajorVersion>.<MinorVersion>.<Patch>
     * @param galleryApplicationVersion Parameters supplied to the update gallery Application Version
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.GalleryApplicationVersionsUpdateResponse>
     */
    update(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, galleryApplicationVersion: Models.GalleryApplicationVersionUpdate, options?: msRest.RequestOptionsBase): Promise<Models.GalleryApplicationVersionsUpdateResponse>;
    /**
     * Retrieves information about a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version resides.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be
     * retrieved.
     * @param [options] The optional parameters
     * @returns Promise<Models.GalleryApplicationVersionsGetResponse>
     */
    get(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, options?: Models.GalleryApplicationVersionsGetOptionalParams): Promise<Models.GalleryApplicationVersionsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version resides.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be
     * retrieved.
     * @param callback The callback
     */
    get(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, callback: msRest.ServiceCallback<Models.GalleryApplicationVersion>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version resides.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be
     * retrieved.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, options: Models.GalleryApplicationVersionsGetOptionalParams, callback: msRest.ServiceCallback<Models.GalleryApplicationVersion>): void;
    /**
     * Delete a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version resides.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be deleted.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * List gallery Application Versions in a gallery Application Definition.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the Shared Application Gallery Application Definition
     * from which the Application Versions are to be listed.
     * @param [options] The optional parameters
     * @returns Promise<Models.GalleryApplicationVersionsListByGalleryApplicationResponse>
     */
    listByGalleryApplication(resourceGroupName: string, galleryName: string, galleryApplicationName: string, options?: msRest.RequestOptionsBase): Promise<Models.GalleryApplicationVersionsListByGalleryApplicationResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the Shared Application Gallery Application Definition
     * from which the Application Versions are to be listed.
     * @param callback The callback
     */
    listByGalleryApplication(resourceGroupName: string, galleryName: string, galleryApplicationName: string, callback: msRest.ServiceCallback<Models.GalleryApplicationVersionList>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the Shared Application Gallery Application Definition
     * from which the Application Versions are to be listed.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByGalleryApplication(resourceGroupName: string, galleryName: string, galleryApplicationName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.GalleryApplicationVersionList>): void;
    /**
     * Create or update a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version is to be created.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be created.
     * Needs to follow semantic version name pattern: The allowed characters are digit and period.
     * Digits must be within the range of a 32-bit integer. Format:
     * <MajorVersion>.<MinorVersion>.<Patch>
     * @param galleryApplicationVersion Parameters supplied to the create or update gallery Application
     * Version operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, galleryApplicationVersion: Models.GalleryApplicationVersion, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Update a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version is to be updated.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be updated.
     * Needs to follow semantic version name pattern: The allowed characters are digit and period.
     * Digits must be within the range of a 32-bit integer. Format:
     * <MajorVersion>.<MinorVersion>.<Patch>
     * @param galleryApplicationVersion Parameters supplied to the update gallery Application Version
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, galleryApplicationVersion: Models.GalleryApplicationVersionUpdate, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Delete a gallery Application Version.
     * @param resourceGroupName The name of the resource group.
     * @param galleryName The name of the Shared Application Gallery in which the Application
     * Definition resides.
     * @param galleryApplicationName The name of the gallery Application Definition in which the
     * Application Version resides.
     * @param galleryApplicationVersionName The name of the gallery Application Version to be deleted.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, galleryName: string, galleryApplicationName: string, galleryApplicationVersionName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * List gallery Application Versions in a gallery Application Definition.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.GalleryApplicationVersionsListByGalleryApplicationNextResponse>
     */
    listByGalleryApplicationNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.GalleryApplicationVersionsListByGalleryApplicationNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByGalleryApplicationNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.GalleryApplicationVersionList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByGalleryApplicationNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.GalleryApplicationVersionList>): void;
}
//# sourceMappingURL=galleryApplicationVersions.d.ts.map