/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import * as Mappers from "../models/communityGalleryImageVersionsMappers";
import * as Parameters from "../models/parameters";
import { ComputeManagementClientContext } from "../computeManagementClientContext";

/** Class representing a CommunityGalleryImageVersions. */
export class CommunityGalleryImageVersions {
  private readonly client: ComputeManagementClientContext;

  /**
   * Create a CommunityGalleryImageVersions.
   * @param {ComputeManagementClientContext} client Reference to the service client.
   */
  constructor(client: ComputeManagementClientContext) {
    this.client = client;
  }

  /**
   * Get a community gallery image version.
   * @param location Resource location.
   * @param publicGalleryName The public name of the community gallery.
   * @param galleryImageName The name of the community gallery image definition.
   * @param galleryImageVersionName The name of the community gallery image version. Needs to follow
   * semantic version name pattern: The allowed characters are digit and period. Digits must be
   * within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
   * @param [options] The optional parameters
   * @returns Promise<Models.CommunityGalleryImageVersionsGetResponse>
   */
  get(location: string, publicGalleryName: string, galleryImageName: string, galleryImageVersionName: string, options?: msRest.RequestOptionsBase): Promise<Models.CommunityGalleryImageVersionsGetResponse>;
  /**
   * @param location Resource location.
   * @param publicGalleryName The public name of the community gallery.
   * @param galleryImageName The name of the community gallery image definition.
   * @param galleryImageVersionName The name of the community gallery image version. Needs to follow
   * semantic version name pattern: The allowed characters are digit and period. Digits must be
   * within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
   * @param callback The callback
   */
  get(location: string, publicGalleryName: string, galleryImageName: string, galleryImageVersionName: string, callback: msRest.ServiceCallback<Models.CommunityGalleryImageVersion>): void;
  /**
   * @param location Resource location.
   * @param publicGalleryName The public name of the community gallery.
   * @param galleryImageName The name of the community gallery image definition.
   * @param galleryImageVersionName The name of the community gallery image version. Needs to follow
   * semantic version name pattern: The allowed characters are digit and period. Digits must be
   * within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
   * @param options The optional parameters
   * @param callback The callback
   */
  get(location: string, publicGalleryName: string, galleryImageName: string, galleryImageVersionName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.CommunityGalleryImageVersion>): void;
  get(location: string, publicGalleryName: string, galleryImageName: string, galleryImageVersionName: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.CommunityGalleryImageVersion>, callback?: msRest.ServiceCallback<Models.CommunityGalleryImageVersion>): Promise<Models.CommunityGalleryImageVersionsGetResponse> {
    return this.client.sendOperationRequest(
      {
        location,
        publicGalleryName,
        galleryImageName,
        galleryImageVersionName,
        options
      },
      getOperationSpec,
      callback) as Promise<Models.CommunityGalleryImageVersionsGetResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/providers/Microsoft.Compute/locations/{location}/communityGalleries/{publicGalleryName}/images/{galleryImageName}/versions/{galleryImageVersionName}",
  urlParameters: [
    Parameters.subscriptionId,
    Parameters.location0,
    Parameters.publicGalleryName,
    Parameters.galleryImageName,
    Parameters.galleryImageVersionName
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.CommunityGalleryImageVersion
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
