/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/connectionMonitorsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ConnectionMonitors. */
var ConnectionMonitors = /** @class */ (function () {
    /**
     * Create a ConnectionMonitors.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ConnectionMonitors(client) {
        this.client = client;
    }
    /**
     * Create or update a connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param parameters Parameters that define the operation to create a connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<Models.ConnectionMonitorsCreateOrUpdateResponse>
     */
    ConnectionMonitors.prototype.createOrUpdate = function (resourceGroupName, networkWatcherName, connectionMonitorName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, networkWatcherName, connectionMonitorName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ConnectionMonitors.prototype.get = function (resourceGroupName, networkWatcherName, connectionMonitorName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ConnectionMonitors.prototype.deleteMethod = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkWatcherName, connectionMonitorName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ConnectionMonitors.prototype.updateTags = function (resourceGroupName, networkWatcherName, connectionMonitorName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    /**
     * Stops the specified connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ConnectionMonitors.prototype.stop = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.beginStop(resourceGroupName, networkWatcherName, connectionMonitorName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Starts the specified connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ConnectionMonitors.prototype.start = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.beginStart(resourceGroupName, networkWatcherName, connectionMonitorName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Query a snapshot of the most recent connection states.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name given to the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<Models.ConnectionMonitorsQueryResponse>
     */
    ConnectionMonitors.prototype.query = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.beginQuery(resourceGroupName, networkWatcherName, connectionMonitorName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ConnectionMonitors.prototype.list = function (resourceGroupName, networkWatcherName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Create or update a connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param parameters Parameters that define the operation to create a connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ConnectionMonitors.prototype.beginCreateOrUpdate = function (resourceGroupName, networkWatcherName, connectionMonitorName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes the specified connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ConnectionMonitors.prototype.beginDeleteMethod = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Stops the specified connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ConnectionMonitors.prototype.beginStop = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            options: options
        }, beginStopOperationSpec, options);
    };
    /**
     * Starts the specified connection monitor.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name of the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ConnectionMonitors.prototype.beginStart = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            options: options
        }, beginStartOperationSpec, options);
    };
    /**
     * Query a snapshot of the most recent connection states.
     * @param resourceGroupName The name of the resource group containing Network Watcher.
     * @param networkWatcherName The name of the Network Watcher resource.
     * @param connectionMonitorName The name given to the connection monitor.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ConnectionMonitors.prototype.beginQuery = function (resourceGroupName, networkWatcherName, connectionMonitorName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            connectionMonitorName: connectionMonitorName,
            options: options
        }, beginQueryOperationSpec, options);
    };
    return ConnectionMonitors;
}());
export { ConnectionMonitors };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionMonitorResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionMonitorResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionMonitorListResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.migrate
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ConnectionMonitor), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionMonitorResult
        },
        201: {
            bodyMapper: Mappers.ConnectionMonitorResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginStopOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}/stop",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginStartOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}/start",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginQueryOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/connectionMonitors/{connectionMonitorName}/query",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.connectionMonitorName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ConnectionMonitorQueryResult
        },
        202: {
            bodyMapper: Mappers.ConnectionMonitorQueryResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
//# sourceMappingURL=connectionMonitors.js.map