/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteCrossConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteCrossConnections. */
var ExpressRouteCrossConnections = /** @class */ (function () {
    /**
     * Create a ExpressRouteCrossConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteCrossConnections(client) {
        this.client = client;
    }
    ExpressRouteCrossConnections.prototype.list = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listOperationSpec, callback);
    };
    ExpressRouteCrossConnections.prototype.listByResourceGroup = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listByResourceGroupOperationSpec, callback);
    };
    ExpressRouteCrossConnections.prototype.get = function (resourceGroupName, crossConnectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Update the specified ExpressRouteCrossConnection.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param parameters Parameters supplied to the update express route crossConnection operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCrossConnectionsCreateOrUpdateResponse>
     */
    ExpressRouteCrossConnections.prototype.createOrUpdate = function (resourceGroupName, crossConnectionName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, crossConnectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCrossConnections.prototype.updateTags = function (resourceGroupName, crossConnectionName, crossConnectionParameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            crossConnectionParameters: crossConnectionParameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    /**
     * Gets the currently advertised ARP table associated with the express route cross connection in a
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCrossConnectionsListArpTableResponse>
     */
    ExpressRouteCrossConnections.prototype.listArpTable = function (resourceGroupName, crossConnectionName, peeringName, devicePath, options) {
        return this.beginListArpTable(resourceGroupName, crossConnectionName, peeringName, devicePath, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the route table summary associated with the express route cross connection in a resource
     * group.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCrossConnectionsListRoutesTableSummaryResponse>
     */
    ExpressRouteCrossConnections.prototype.listRoutesTableSummary = function (resourceGroupName, crossConnectionName, peeringName, devicePath, options) {
        return this.beginListRoutesTableSummary(resourceGroupName, crossConnectionName, peeringName, devicePath, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Gets the currently advertised routes table associated with the express route cross connection in
     * a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCrossConnectionsListRoutesTableResponse>
     */
    ExpressRouteCrossConnections.prototype.listRoutesTable = function (resourceGroupName, crossConnectionName, peeringName, devicePath, options) {
        return this.beginListRoutesTable(resourceGroupName, crossConnectionName, peeringName, devicePath, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Update the specified ExpressRouteCrossConnection.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param parameters Parameters supplied to the update express route crossConnection operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCrossConnections.prototype.beginCreateOrUpdate = function (resourceGroupName, crossConnectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Gets the currently advertised ARP table associated with the express route cross connection in a
     * resource group.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCrossConnections.prototype.beginListArpTable = function (resourceGroupName, crossConnectionName, peeringName, devicePath, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            peeringName: peeringName,
            devicePath: devicePath,
            options: options
        }, beginListArpTableOperationSpec, options);
    };
    /**
     * Gets the route table summary associated with the express route cross connection in a resource
     * group.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCrossConnections.prototype.beginListRoutesTableSummary = function (resourceGroupName, crossConnectionName, peeringName, devicePath, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            peeringName: peeringName,
            devicePath: devicePath,
            options: options
        }, beginListRoutesTableSummaryOperationSpec, options);
    };
    /**
     * Gets the currently advertised routes table associated with the express route cross connection in
     * a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param crossConnectionName The name of the ExpressRouteCrossConnection.
     * @param peeringName The name of the peering.
     * @param devicePath The path of the device.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCrossConnections.prototype.beginListRoutesTable = function (resourceGroupName, crossConnectionName, peeringName, devicePath, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            crossConnectionName: crossConnectionName,
            peeringName: peeringName,
            devicePath: devicePath,
            options: options
        }, beginListRoutesTableOperationSpec, options);
    };
    ExpressRouteCrossConnections.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    ExpressRouteCrossConnections.prototype.listByResourceGroupNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByResourceGroupNextOperationSpec, callback);
    };
    return ExpressRouteCrossConnections;
}());
export { ExpressRouteCrossConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/expressRouteCrossConnections",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "crossConnectionParameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteCrossConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListArpTableOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}/arpTables/{devicePath}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.peeringName,
        Parameters.devicePath,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitsArpTableListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListRoutesTableSummaryOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}/routeTablesSummary/{devicePath}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.peeringName,
        Parameters.devicePath,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionsRoutesTableSummaryListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginListRoutesTableOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCrossConnections/{crossConnectionName}/peerings/{peeringName}/routeTables/{devicePath}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.crossConnectionName,
        Parameters.peeringName,
        Parameters.devicePath,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitsRoutesTableListResult
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCrossConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteCrossConnections.js.map