/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/securityRulesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a SecurityRules. */
var SecurityRules = /** @class */ (function () {
    /**
     * Create a SecurityRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function SecurityRules(client) {
        this.client = client;
    }
    /**
     * Deletes the specified network security rule.
     * @param resourceGroupName The name of the resource group.
     * @param networkSecurityGroupName The name of the network security group.
     * @param securityRuleName The name of the security rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    SecurityRules.prototype.deleteMethod = function (resourceGroupName, networkSecurityGroupName, securityRuleName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkSecurityGroupName, securityRuleName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    SecurityRules.prototype.get = function (resourceGroupName, networkSecurityGroupName, securityRuleName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkSecurityGroupName: networkSecurityGroupName,
            securityRuleName: securityRuleName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a security rule in the specified network security group.
     * @param resourceGroupName The name of the resource group.
     * @param networkSecurityGroupName The name of the network security group.
     * @param securityRuleName The name of the security rule.
     * @param securityRuleParameters Parameters supplied to the create or update network security rule
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityRulesCreateOrUpdateResponse>
     */
    SecurityRules.prototype.createOrUpdate = function (resourceGroupName, networkSecurityGroupName, securityRuleName, securityRuleParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, networkSecurityGroupName, securityRuleName, securityRuleParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    SecurityRules.prototype.list = function (resourceGroupName, networkSecurityGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkSecurityGroupName: networkSecurityGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified network security rule.
     * @param resourceGroupName The name of the resource group.
     * @param networkSecurityGroupName The name of the network security group.
     * @param securityRuleName The name of the security rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    SecurityRules.prototype.beginDeleteMethod = function (resourceGroupName, networkSecurityGroupName, securityRuleName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkSecurityGroupName: networkSecurityGroupName,
            securityRuleName: securityRuleName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a security rule in the specified network security group.
     * @param resourceGroupName The name of the resource group.
     * @param networkSecurityGroupName The name of the network security group.
     * @param securityRuleName The name of the security rule.
     * @param securityRuleParameters Parameters supplied to the create or update network security rule
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    SecurityRules.prototype.beginCreateOrUpdate = function (resourceGroupName, networkSecurityGroupName, securityRuleName, securityRuleParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkSecurityGroupName: networkSecurityGroupName,
            securityRuleName: securityRuleName,
            securityRuleParameters: securityRuleParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    SecurityRules.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return SecurityRules;
}());
export { SecurityRules };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkSecurityGroups/{networkSecurityGroupName}/securityRules/{securityRuleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkSecurityGroupName,
        Parameters.securityRuleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkSecurityGroups/{networkSecurityGroupName}/securityRules",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkSecurityGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityRuleListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkSecurityGroups/{networkSecurityGroupName}/securityRules/{securityRuleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkSecurityGroupName,
        Parameters.securityRuleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkSecurityGroups/{networkSecurityGroupName}/securityRules/{securityRuleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkSecurityGroupName,
        Parameters.securityRuleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "securityRuleParameters",
        mapper: __assign(__assign({}, Mappers.SecurityRule), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.SecurityRule
        },
        201: {
            bodyMapper: Mappers.SecurityRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.SecurityRuleListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=securityRules.js.map