/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/vpnConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VpnConnections. */
var VpnConnections = /** @class */ (function () {
    /**
     * Create a VpnConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VpnConnections(client) {
        this.client = client;
    }
    VpnConnections.prototype.get = function (resourceGroupName, gatewayName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            connectionName: connectionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates a vpn connection to a scalable vpn gateway if it doesn't exist else updates the existing
     * connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param vpnConnectionParameters Parameters supplied to create or Update a VPN Connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsCreateOrUpdateResponse>
     */
    VpnConnections.prototype.createOrUpdate = function (resourceGroupName, gatewayName, connectionName, vpnConnectionParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, gatewayName, connectionName, vpnConnectionParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a vpn connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VpnConnections.prototype.deleteMethod = function (resourceGroupName, gatewayName, connectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, gatewayName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Starts packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsStartPacketCaptureResponse>
     */
    VpnConnections.prototype.startPacketCapture = function (resourceGroupName, gatewayName, vpnConnectionName, options) {
        return this.beginStartPacketCapture(resourceGroupName, gatewayName, vpnConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Stops packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsStopPacketCaptureResponse>
     */
    VpnConnections.prototype.stopPacketCapture = function (resourceGroupName, gatewayName, vpnConnectionName, options) {
        return this.beginStopPacketCapture(resourceGroupName, gatewayName, vpnConnectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VpnConnections.prototype.listByVpnGateway = function (resourceGroupName, gatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            options: options
        }, listByVpnGatewayOperationSpec, callback);
    };
    /**
     * Creates a vpn connection to a scalable vpn gateway if it doesn't exist else updates the existing
     * connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param vpnConnectionParameters Parameters supplied to create or Update a VPN Connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnConnections.prototype.beginCreateOrUpdate = function (resourceGroupName, gatewayName, connectionName, vpnConnectionParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            connectionName: connectionName,
            vpnConnectionParameters: vpnConnectionParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a vpn connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnConnections.prototype.beginDeleteMethod = function (resourceGroupName, gatewayName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            connectionName: connectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Starts packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnConnections.prototype.beginStartPacketCapture = function (resourceGroupName, gatewayName, vpnConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            vpnConnectionName: vpnConnectionName,
            options: options
        }, beginStartPacketCaptureOperationSpec, options);
    };
    /**
     * Stops packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VpnConnections.prototype.beginStopPacketCapture = function (resourceGroupName, gatewayName, vpnConnectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            gatewayName: gatewayName,
            vpnConnectionName: vpnConnectionName,
            options: options
        }, beginStopPacketCaptureOperationSpec, options);
    };
    VpnConnections.prototype.listByVpnGatewayNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByVpnGatewayNextOperationSpec, callback);
    };
    return VpnConnections;
}());
export { VpnConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.VpnConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByVpnGatewayOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "vpnConnectionParameters",
        mapper: __assign(__assign({}, Mappers.VpnConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.VpnConnection
        },
        201: {
            bodyMapper: Mappers.VpnConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{connectionName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.connectionName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginStartPacketCaptureOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{vpnConnectionName}/startpacketcapture",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.vpnConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: [
            "options",
            "parameters"
        ],
        mapper: Mappers.VpnConnectionPacketCaptureStartParameters
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginStopPacketCaptureOperationSpec = {
    httpMethod: "POST",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnGateways/{gatewayName}/vpnConnections/{vpnConnectionName}/stoppacketcapture",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.gatewayName,
        Parameters.vpnConnectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: [
            "options",
            "parameters"
        ],
        mapper: Mappers.VpnConnectionPacketCaptureStopParameters
    },
    responses: {
        200: {
            bodyMapper: {
                serializedName: "parsedResponse",
                type: {
                    name: "String"
                }
            }
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByVpnGatewayNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnConnectionsResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=vpnConnections.js.map