import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VpnSiteLinks. */
export declare class VpnSiteLinks {
    private readonly client;
    /**
     * Create a VpnSiteLinks.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Retrieves the details of a VPN site link.
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param vpnSiteLinkName The name of the VpnSiteLink being retrieved.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnSiteLinksGetResponse>
     */
    get(resourceGroupName: string, vpnSiteName: string, vpnSiteLinkName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnSiteLinksGetResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param vpnSiteLinkName The name of the VpnSiteLink being retrieved.
     * @param callback The callback
     */
    get(resourceGroupName: string, vpnSiteName: string, vpnSiteLinkName: string, callback: msRest.ServiceCallback<Models.VpnSiteLink>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param vpnSiteLinkName The name of the VpnSiteLink being retrieved.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, vpnSiteName: string, vpnSiteLinkName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VpnSiteLink>): void;
    /**
     * Lists all the vpnSiteLinks in a resource group for a vpn site.
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnSiteLinksListByVpnSiteResponse>
     */
    listByVpnSite(resourceGroupName: string, vpnSiteName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnSiteLinksListByVpnSiteResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param callback The callback
     */
    listByVpnSite(resourceGroupName: string, vpnSiteName: string, callback: msRest.ServiceCallback<Models.ListVpnSiteLinksResult>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnSite(resourceGroupName: string, vpnSiteName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnSiteLinksResult>): void;
    /**
     * Lists all the vpnSiteLinks in a resource group for a vpn site.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnSiteLinksListByVpnSiteNextResponse>
     */
    listByVpnSiteNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnSiteLinksListByVpnSiteNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByVpnSiteNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVpnSiteLinksResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnSiteNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnSiteLinksResult>): void;
}
//# sourceMappingURL=vpnSiteLinks.d.ts.map