/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import * as Mappers from "../models/serviceTagInformationOperationsMappers";
import * as Parameters from "../models/parameters";
import { NetworkManagementClientContext } from "../networkManagementClientContext";

/** Class representing a ServiceTagInformationOperations. */
export class ServiceTagInformationOperations {
  private readonly client: NetworkManagementClientContext;

  /**
   * Create a ServiceTagInformationOperations.
   * @param {NetworkManagementClientContext} client Reference to the service client.
   */
  constructor(client: NetworkManagementClientContext) {
    this.client = client;
  }

  /**
   * Gets a list of service tag information resources with pagination.
   * @param location The location that will be used as a reference for cloud (not as a filter based
   * on location, you will get the list of service tags with prefix details across all regions but
   * limited to the cloud that your subscription belongs to).
   * @param [options] The optional parameters
   * @returns Promise<Models.ServiceTagInformationListResponse>
   */
  list(location: string, options?: Models.ServiceTagInformationListOptionalParams): Promise<Models.ServiceTagInformationListResponse>;
  /**
   * @param location The location that will be used as a reference for cloud (not as a filter based
   * on location, you will get the list of service tags with prefix details across all regions but
   * limited to the cloud that your subscription belongs to).
   * @param callback The callback
   */
  list(location: string, callback: msRest.ServiceCallback<Models.ServiceTagInformationListResult>): void;
  /**
   * @param location The location that will be used as a reference for cloud (not as a filter based
   * on location, you will get the list of service tags with prefix details across all regions but
   * limited to the cloud that your subscription belongs to).
   * @param options The optional parameters
   * @param callback The callback
   */
  list(location: string, options: Models.ServiceTagInformationListOptionalParams, callback: msRest.ServiceCallback<Models.ServiceTagInformationListResult>): void;
  list(location: string, options?: Models.ServiceTagInformationListOptionalParams | msRest.ServiceCallback<Models.ServiceTagInformationListResult>, callback?: msRest.ServiceCallback<Models.ServiceTagInformationListResult>): Promise<Models.ServiceTagInformationListResponse> {
    return this.client.sendOperationRequest(
      {
        location,
        options
      },
      listOperationSpec,
      callback) as Promise<Models.ServiceTagInformationListResponse>;
  }

  /**
   * Gets a list of service tag information resources with pagination.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ServiceTagInformationListNextResponse>
   */
  listNext(nextPageLink: string, options?: Models.ServiceTagInformationListNextOptionalParams): Promise<Models.ServiceTagInformationListNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ServiceTagInformationListResult>): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listNext(nextPageLink: string, options: Models.ServiceTagInformationListNextOptionalParams, callback: msRest.ServiceCallback<Models.ServiceTagInformationListResult>): void;
  listNext(nextPageLink: string, options?: Models.ServiceTagInformationListNextOptionalParams | msRest.ServiceCallback<Models.ServiceTagInformationListResult>, callback?: msRest.ServiceCallback<Models.ServiceTagInformationListResult>): Promise<Models.ServiceTagInformationListNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listNextOperationSpec,
      callback) as Promise<Models.ServiceTagInformationListNextResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const listOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/locations/{location}/serviceTagDetails",
  urlParameters: [
    Parameters.location0,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0,
    Parameters.noAddressPrefixes,
    Parameters.tagName
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.ServiceTagInformationListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [
    Parameters.nextPageLink
  ],
  queryParameters: [
    Parameters.apiVersion0,
    Parameters.noAddressPrefixes,
    Parameters.tagName
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.ServiceTagInformationListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
