import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { PrivateDnsManagementClientContext } from "../privateDnsManagementClientContext";
/** Class representing a RecordSets. */
export declare class RecordSets {
    private readonly client;
    /**
     * Create a RecordSets.
     * @param {PrivateDnsManagementClientContext} client Reference to the service client.
     */
    constructor(client: PrivateDnsManagementClientContext);
    /**
     * Creates or updates a record set within a Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Record sets of type SOA can be
     * updated but not created (they are created when the Private DNS zone is created). Possible values
     * include: 'A', 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, parameters: Models.RecordSet, options?: Models.RecordSetsCreateOrUpdateOptionalParams): Promise<Models.RecordSetsCreateOrUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Record sets of type SOA can be
     * updated but not created (they are created when the Private DNS zone is created). Possible values
     * include: 'A', 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, parameters: Models.RecordSet, callback: msRest.ServiceCallback<Models.RecordSet>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Record sets of type SOA can be
     * updated but not created (they are created when the Private DNS zone is created). Possible values
     * include: 'A', 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, parameters: Models.RecordSet, options: Models.RecordSetsCreateOrUpdateOptionalParams, callback: msRest.ServiceCallback<Models.RecordSet>): void;
    /**
     * Updates a record set within a Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsUpdateResponse>
     */
    update(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, parameters: Models.RecordSet, options?: Models.RecordSetsUpdateOptionalParams): Promise<Models.RecordSetsUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param parameters Parameters supplied to the Update operation.
     * @param callback The callback
     */
    update(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, parameters: Models.RecordSet, callback: msRest.ServiceCallback<Models.RecordSet>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param parameters Parameters supplied to the Update operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    update(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, parameters: Models.RecordSet, options: Models.RecordSetsUpdateOptionalParams, callback: msRest.ServiceCallback<Models.RecordSet>): void;
    /**
     * Deletes a record set from a Private DNS zone. This operation cannot be undone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Record sets of type SOA cannot be
     * deleted (they are deleted when the Private DNS zone is deleted). Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, options?: Models.RecordSetsDeleteMethodOptionalParams): Promise<msRest.RestResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Record sets of type SOA cannot be
     * deleted (they are deleted when the Private DNS zone is deleted). Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Record sets of type SOA cannot be
     * deleted (they are deleted when the Private DNS zone is deleted). Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, options: Models.RecordSetsDeleteMethodOptionalParams, callback: msRest.ServiceCallback<void>): void;
    /**
     * Gets a record set.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsGetResponse>
     */
    get(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, options?: msRest.RequestOptionsBase): Promise<Models.RecordSetsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param callback The callback
     */
    get(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, callback: msRest.ServiceCallback<Models.RecordSet>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of DNS record in this record set. Possible values include: 'A',
     * 'AAAA', 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param relativeRecordSetName The name of the record set, relative to the name of the zone.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, relativeRecordSetName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RecordSet>): void;
    /**
     * Lists the record sets of a specified type in a Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of record sets to enumerate. Possible values include: 'A', 'AAAA',
     * 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsListByTypeResponse>
     */
    listByType(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, options?: Models.RecordSetsListByTypeOptionalParams): Promise<Models.RecordSetsListByTypeResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of record sets to enumerate. Possible values include: 'A', 'AAAA',
     * 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param callback The callback
     */
    listByType(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param recordType The type of record sets to enumerate. Possible values include: 'A', 'AAAA',
     * 'CNAME', 'MX', 'PTR', 'SOA', 'SRV', 'TXT'
     * @param options The optional parameters
     * @param callback The callback
     */
    listByType(resourceGroupName: string, privateZoneName: string, recordType: Models.RecordType, options: Models.RecordSetsListByTypeOptionalParams, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * Lists all record sets in a Private DNS zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsListResponse>
     */
    list(resourceGroupName: string, privateZoneName: string, options?: Models.RecordSetsListOptionalParams): Promise<Models.RecordSetsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param callback The callback
     */
    list(resourceGroupName: string, privateZoneName: string, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, privateZoneName: string, options: Models.RecordSetsListOptionalParams, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * Lists the record sets of a specified type in a Private DNS zone.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsListByTypeNextResponse>
     */
    listByTypeNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RecordSetsListByTypeNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByTypeNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByTypeNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * Lists all record sets in a Private DNS zone.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RecordSetsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.RecordSetsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.RecordSetListResult>): void;
}
//# sourceMappingURL=recordSets.d.ts.map